# Itomori

Itomori is a clean, minimal, and fully keyboard-powered notes app built with Python. It focuses on simplicity, speed, and staying out of your way—so you can just write. It's designed for taking quick notes , that's why it is great for quick notes.

# Preview

https://raw.githubusercontent.com/TheAhumMaitra/Itomori/main/assests/videos/Show_off.mp4

# ✨ Features

1. Minimal and distraction-free

2. Fully keyboard-driven UI

3. Lightweight and fast

4. Stores note simply in json format

5. Easy for quick notes

# 🛠️ Installation

## Windows

**Installation with `uv`:**

```
uv tool install git+https://github.com/TheAhumMaitra/Itomori.git
```

***Done , now launch with just ```Itomori`` command***

**Manual installation:**

**Pre-requirements : git, uv, python 3.14 installed**
***Note : It can work on older Python version but it is not recommended.**

***Steps :***

1. Clone this repo

```
git clone https://github.com/TheAhumMaitra/Itomori.git
```

2. Go to the Itomori folder

It's saved where you cloned this repo

```
cd Itomori
```

3. Install it

```
pip install .
 ```

**Done!**

## Mac OS

**Installation with `uv`:**

```
uv tool install git+https://github.com/TheAhumMaitra/Itomori.git
```

***Done , now launch with just ``Itomori`` command***

## Linux

**Installation with `uv`:**

```
uv tool install git+https://github.com/TheAhumMaitra/Itomori.git
```

***Done , now launch with just ```Itomori`` command***


**Installation with `curl`:**

```
curl -sSL "https://raw.githubusercontent.com/TheAhumMaitra/Itomori/refs/heads/main/Linux%20Install%20Scripts/install.sh" | bash
```
**Note : It's not recommended**

# 💬 Contribute

Feel free to contribute ideas, improvements, or bug fixes. PRs are always welcome!

# License

[`License`](License.md)

### ⚠ Logs warning : This app is designed to take logs , so you need to delete them mannualy, Go to `home / Itomori` and delete the `.logs/app.log`'s content, not the file.

# Thanks

❤️ Thanks for checking out Itomori!

Made with love and minimalism and coffee and Textual.
